@@ -24,7 +24,7 @@ def auth_token():
 
 
 def _token_username():
-    decoded_token = jwt.decode(auth_token(), verify=False)
+    decoded_token = jwt.decode(auth_token(), options={"verify_signature": False})
     if decoded_token.get("https://identity.zalando.com/realm") == "users":
         return decoded_token.get("https://identity.zalando.com/managed-id")
 
